==> igniteui-react-18.2.2-beta.0.tgz: package/esm5/lib/RangeSlider.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { SliderBase } from "./SliderBase";
import { markType } from "igniteui-react-core";
import { RangeSliderValueEventArgs } from "./RangeSliderValueEventArgs";
/**
 * @hidden
 */
var RangeSlider = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(RangeSlider, _super);
    function RangeSlider() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.input = null;
        _this.change = null;
        return _this;
    }
    Object.defineProperty(RangeSlider.prototype, "aa", {
        get: function () {
            var ret_ = this.e.m("lower");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.u("lower", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(RangeSlider.prototype, "ab", {
        get: function () {
            var ret_ = this.e.m("upper");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.u("upper", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(RangeSlider.prototype, "ac", {
        get: function () {
            var ret_ = this.e.m("ariaLabelLower");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.u("ariaLabelLower", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(RangeSlider.prototype, "ad", {
        get: function () {
            var ret_ = this.e.m("ariaLabelUpper");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.u("ariaLabelUpper", value_);
        },
        enumerable: false,
        configurable: true
    });
    RangeSlider.prototype.inputChanged = function () {
        var _this = this;
        if (this.input != null) {
            this.e.q("input", function (a) { return _this.input(_this, RangeSliderValueEventArgs.b(a)); });
        }
        else {
            this.e.t("input");
        }
    };
    RangeSlider.prototype.changeChanged = function () {
        var _this = this;
        if (this.change != null) {
            this.e.q("change", function (a) { return _this.change(_this, RangeSliderValueEventArgs.b(a)); });
        }
        else {
            this.e.t("change");
        }
    };
    RangeSlider.$t = markType(RangeSlider, 'RangeSlider', SliderBase.$);
    return RangeSlider;
}(SliderBase));
export { RangeSlider };

==> igniteui-react-18.3.0-beta.0.tgz: package/esm5/lib/RangeSlider.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { SliderBase } from "./SliderBase";
import { markType } from "igniteui-react-core";
import { RangeSliderValueEventArgs } from "./RangeSliderValueEventArgs";
/**
 * @hidden
 */
var RangeSlider = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(RangeSlider, _super);
    function RangeSlider() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.input = null;
        _this.change = null;
        return _this;
    }
    Object.defineProperty(RangeSlider.prototype, "aa", {
        get: function () {
            var ret_ = this.e.n("lower");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.v("lower", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(RangeSlider.prototype, "ab", {
        get: function () {
            var ret_ = this.e.n("upper");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.v("upper", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(RangeSlider.prototype, "ac", {
        get: function () {
            var ret_ = this.e.n("ariaLabelLower");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.v("ariaLabelLower", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(RangeSlider.prototype, "ad", {
        get: function () {
            var ret_ = this.e.n("ariaLabelUpper");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.v("ariaLabelUpper", value_);
        },
        enumerable: false,
        configurable: true
    });
    RangeSlider.prototype.inputChanged = function () {
        var _this = this;
        if (this.input != null) {
            this.e.r("input", function (a) { return _this.input(_this, RangeSliderValueEventArgs.b(a)); });
        }
        else {
            this.e.u("input");
        }
    };
    RangeSlider.prototype.changeChanged = function () {
        var _this = this;
        if (this.change != null) {
            this.e.r("change", function (a) { return _this.change(_this, RangeSliderValueEventArgs.b(a)); });
        }
        else {
            this.e.u("change");
        }
    };
    RangeSlider.$t = markType(RangeSlider, 'RangeSlider', SliderBase.$);
    return RangeSlider;
}(SliderBase));
export { RangeSlider };
